% Auto-generated chapter 42 for bukhari
% Hadiths in this chapter: 31

\hadithdefcmd{bukhari}{2351}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِقَدَحٍ فَشَرِبَ مِنْهُ، وَعَنْ يَمِينِهِ غُلاَمٌ أَصْغَرُ الْقَوْمِ، وَالأَشْيَاخُ عَنْ يَسَارِهِ فَقَالَ ‏ "‏ يَا غُلاَمُ أَتَأْذَنُ لِي أَنْ أُعْطِيَهُ الأَشْيَاخَ ‏"‏‏.‏ قَالَ مَا كُنْتُ لأُوثِرَ بِفَضْلِي مِنْكَ أَحَدًا يَا رَسُولَ اللَّهِ‏.‏ فَأَعْطَاهُ إِيَّاهُ‏.‏\hadithno{2351}\hadithtrans{Narrated Sahl bin Sa`d:A tumbler (full of milk or water) was brought to the Prophet (ﷺ) who drank from it, while on his right side there was sitting a boy who was the youngest of those who were present and on his left side there were old men. The Prophet (ﷺ) asked, "O boy, will you allow me to give it (i.e. the rest of the drink) to the old men?" The boy said, "O Allah's Messenger (ﷺ)! I will not give preference to anyone over me to drink the rest of it from which you have drunk." So, the Prophet (ﷺ) gave it to him}}
\hadithdefcmd{bukhari}{2352}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ أَنَّهَا حُلِبَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم شَاةٌ دَاجِنٌ وَهْىَ فِي دَارِ أَنَسِ بْنِ مَالِكٍ، وَشِيبَ لَبَنُهَا بِمَاءٍ مِنَ الْبِئْرِ الَّتِي فِي دَارِ أَنَسٍ، فَأَعْطَى رَسُولَ اللَّهِ صلى الله عليه وسلم الْقَدَحَ فَشَرِبَ مِنْهُ، حَتَّى إِذَا نَزَعَ الْقَدَحَ مِنْ فِيهِ، وَعَلَى يَسَارِهِ أَبُو بَكْرٍ وَعَنْ يَمِينِهِ أَعْرَابِيٌّ فَقَالَ عُمَرُ وَخَافَ أَنْ يُعْطِيَهُ الأَعْرَابِيَّ أَعْطِ أَبَا بَكْرٍ يَا رَسُولَ اللَّهِ عِنْدَكَ‏.‏ فَأَعْطَاهُ الأَعْرَابِيَّ الَّذِي عَلَى يَمِينِهِ، ثُمَّ قَالَ ‏ "‏ الأَيْمَنَ فَالأَيْمَنَ ‏"‏‏.‏\hadithno{2352}\hadithtrans{Narrated Az-Zuhri:Anas bin Malik said, that once a domestic sheep was milked for Allah's Messenger (ﷺ) while he was in the house of Anas bin Malik. The milk was mixed with water drawn from the well in Anas's house. A tumbler of it was presented to Allah's Messenger (ﷺ) who drank from it. Then Abu Bakr was sitting on his left side and a bedouin on his right side. When the Prophet (ﷺ) removed the tumbler from his mouth, `Umar was afraid that the Prophet (ﷺ) might give it to the bedouin, so he said. "O Allah's Messenger (ﷺ)! Give it to Abu Bakr who is sitting by your side." But the Prophet (ﷺ) gave it to the bedouin, who was to his right and said, "You should start with the one on your right side}}
\hadithdefcmd{bukhari}{2353}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُمْنَعُ فَضْلُ الْمَاءِ لِيُمْنَعَ بِهِ الْكَلأُ ‏"‏‏.‏\hadithno{2353}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Do not withhold the superfluous water, for that will prevent people from grazing their cattle}}
\hadithdefcmd{bukhari}{2354}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَمْنَعُوا فَضْلَ الْمَاءِ لِتَمْنَعُوا بِهِ فَضْلَ الْكَلإِ ‏"‏‏.‏\hadithno{2354}\hadithtrans{Narrated Abu Huraira:that Allah's Messenger (ﷺ) said, "Do not withhold the superfluous water in order to withhold the superfluous grass}}
\hadithdefcmd{bukhari}{2355}{حَدَّثَنَا مَحْمُودٌ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَعْدِنُ جُبَارٌ، وَالْبِئْرُ جُبَارٌ، وَالْعَجْمَاءُ جُبَارٌ، وَفِي الرِّكَازِ الْخُمُسُ ‏"‏‏.‏\hadithno{2355}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "No bloodmoney will be charged if somebody dies in a mine or in a well or is killed by an animal; and if somebody finds a treasure in his land he has to give one-fifth of it to the Government}}
\hadithdefcmd{bukhari}{2357}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ يَقْتَطِعُ بِهَا مَالَ امْرِئٍ، هُوَ عَلَيْهَا فَاجِرٌ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ‏"‏ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ الآيَةَ‏.‏ فَجَاءَ الأَشْعَثُ فَقَالَ مَا حَدَّثَكُمْ أَبُو عَبْدِ الرَّحْمَنِ، فِيَّ أُنْزِلَتْ هَذِهِ الآيَةُ، كَانَتْ لِي بِئْرٌ فِي أَرْضِ ابْنِ عَمٍّ لِي فَقَالَ لِي ‏"‏ شُهُودَكَ ‏"‏‏.‏ قُلْتُ مَا لِي شُهُودٌ‏.‏ قَالَ ‏"‏ فَيَمِينَهُ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِذًا يَحْلِفَ‏.‏ فَذَكَرَ النَّبِيُّ صلى الله عليه وسلم هَذَا الْحَدِيثَ، فَأَنْزَلَ اللَّهُ ذَلِكَ تَصْدِيقًا لَهُ‏.‏\hadithno{2357}\hadithtrans{Narrated `Abdullah (bin Mas`ud):The Prophet (ﷺ) said, "Whoever takes a false oath to deprive somebody of his property will meet Allah while He will be angry with him." Allah revealed: 'Verily those who purchase a little gain at the cost of Allah's covenant, and their oaths.' ........(3.77) Al-Ashath came (to the place where `Abdullah was narrating) and said, "What has Abu `Abdur- Rahman (i.e. `Abdullah) been telling you? This verse was revealed concerning me. I had a well in the land of a cousin of mine. The Prophet (ﷺ) asked me to bring witnesses (to confirm my claim). I said, 'I don't have witnesses.' He said, 'Let the defendant take an oath then.' I said, 'O Allah's Messenger (ﷺ)! He will take a (false) oath immediately.' Then the Prophet (ﷺ) mentioned the above narration and Allah revealed the verse to confirm what he had said." (See Hadith No)}}
\hadithdefcmd{bukhari}{2358}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ أَبَا صَالِحٍ، يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ثَلاَثَةٌ لاَ يَنْظُرُ اللَّهُ إِلَيْهِمْ يَوْمَ الْقِيَامَةِ، وَلاَ يُزَكِّيهِمْ، وَلَهُمْ عَذَابٌ أَلِيمٌ رَجُلٌ كَانَ لَهُ فَضْلُ مَاءٍ بِالطَّرِيقِ، فَمَنَعَهُ مِنِ ابْنِ السَّبِيلِ، وَرَجُلٌ بَايَعَ إِمَامًا لاَ يُبَايِعُهُ إِلاَّ لِدُنْيَا، فَإِنْ أَعْطَاهُ مِنْهَا رَضِيَ، وَإِنْ لَمْ يُعْطِهِ مِنْهَا سَخِطَ، وَرَجُلٌ أَقَامَ سِلْعَتَهُ بَعْدَ الْعَصْرِ، فَقَالَ وَاللَّهِ الَّذِي لاَ إِلَهَ غَيْرُهُ لَقَدْ أَعْطَيْتُ بِهَا كَذَا وَكَذَا، فَصَدَّقَهُ رَجُلٌ‏"‏ ثُمَّ قَرَأَ هَذِهِ الآيَةَ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏\hadithno{2358}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There are three persons whom Allah will not look at on the Day of Resurrection, nor will he purify them and theirs shall be a severe punishment. They are: -1. A man who possessed superfluous water on a way and he withheld it from travelers. -2. A man who gave a pledge of allegiance to a ruler and he gave it only for worldly benefits. If the ruler gives him something he gets satisfied, and if the ruler withholds something from him, he gets dissatisfied. -3. And a man who displayed his goods for sale after the `Asr prayer and he said, 'By Allah, except Whom None has the right to be worshipped, I have been given so much for my goods,' and somebody believes him (and buys them). The Prophet (ﷺ) then recited: "Verily! Those who purchase a little gain at the cost of Allah's Covenant and their oaths}}
\hadithdefcmd{bukhari}{2359}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ ـ رضى الله عنهما ـ أَنَّهُ حَدَّثَهُ أَنَّ رَجُلاً مِنَ الأَنْصَارِ خَاصَمَ الزُّبَيْرَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فِي شِرَاجِ الْحَرَّةِ الَّتِي يَسْقُونَ بِهَا النَّخْلَ فَقَالَ الأَنْصَارِيُّ سَرِّحِ الْمَاءَ يَمُرُّ فَأَبَى عَلَيْهِ، فَاخْتَصَمَا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلزُّبَيْرِ ‏"‏ اسْقِ يَا زُبَيْرُ، ثُمَّ أَرْسِلِ الْمَاء إِلَى جَارِكَ ‏"‏‏.‏ فَغَضِبَ الأَنْصَارِيُّ، فَقَالَ أَنْ كَانَ ابْنَ عَمَّتِكَ‏.‏ فَتَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ اسْقِ يَا زُبَيْرُ، ثُمَّ احْبِسِ الْمَاءَ، حَتَّى يَرْجِعَ إِلَى الْجَدْرِ ‏"‏‏.‏ فَقَالَ الزُّبَيْرُ وَاللَّهِ إِنِّي لأَحْسِبُ هَذِهِ الآيَةَ نَزَلَتْ فِي ذَلِكَ ‏\{‏فَلاَ وَرَبِّكَ لاَ يُؤْمِنُونَ حَتَّى يُحَكِّمُوكَ فِيمَا شَجَرَ بَيْنَهُمْ‏\}‏‏.‏\hadithno{2359}\hadithtrans{Narrated `Abdullah bin Az-Zubair:An Ansari man quarreled with Az-Zubair in the presence of the Prophet (ﷺ) about the Harra Canals which were used for irrigating the date-palms. The Ansari man said to Az-Zubair, "Let the water pass' but Az-Zubair refused to do so. So, the case was brought before the Prophet (ﷺ) who said to Az-Zubair, "O Zubair! Irrigate (your land) and then let the water pass to your neighbor." On that the Ansari got angry and said to the Prophet, "Is it because he (i.e. Zubair) is your aunt's son?" On that the color of the face of Allah's Messenger (ﷺ) changed (because of anger) and he said, "O Zubair! Irrigate (your land) and then withhold the water till it reaches the walls between the pits round the trees." Zubair said, "By Allah, I think that the following verse was revealed on this occasion": "But no, by your Lord They can have No faith Until they make you judge In all disputes between them}}
\hadithdefcmd{bukhari}{2361}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، قَالَ خَاصَمَ الزُّبَيْرَ رَجُلٌ مِنَ الأَنْصَارِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا زُبَيْرُ اسْقِ ثُمَّ أَرْسِلْ ‏"‏‏.‏ فَقَالَ الأَنْصَارِيُّ إِنَّهُ ابْنُ عَمَّتِكَ‏.‏ فَقَالَ عَلَيْهِ السَّلاَمُ ‏"‏ اسْقِ يَا زُبَيْرُ، ثُمَّ يَبْلُغُ الْمَاءُ الْجَدْرَ، ثُمَّ أَمْسِكْ ‏"‏‏.‏ فَقَالَ الزُّبَيْرُ فَأَحْسِبُ هَذِهِ الآيَةَ نَزَلَتْ فِي ذَلِكَ ‏\{‏َلاَ وَرَبِّكَ لاَ يُؤْمِنُونَ حَتَّى يُحَكِّمُوكَ فِيمَا شَجَرَ بَيْنَهُمْ‏\}‏‏.‏ قَالَ مُحَمَّدُ بْنُ الْعَبَّاسِ قَالَ أَبُو عَبْدِ اللَّهِ لَيْسَ أَحَدٌ يَذْكُرُ عُرْوَةَ عَنْ عَبْدِ اللَّهِ، إِلاَّ اللَّيْثُ فَقَطْ‏.‏\hadithno{2361}\hadithtrans{Narrated `Urwa:When a man from the Ansar quarreled with Az-Zubair, the Prophet (ﷺ) said, "O Zubair! Irrigate (your land) first and then let the water flow (to the land of the others)." "On that the Ansari said, (to the Prophet), "It is because he is your aunt's son." On that the Prophet (ﷺ) said, "O Zubair! Irrigate till the water reaches the walls between the pits around the trees and then stop (i.e. let the water go to the other's land)." I think the following verse was revealed concerning this event: "But no, by your Lord They can have No faith Until they make you judge In all disputes between them}}
\hadithdefcmd{bukhari}{2362}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا مَخْلَدٌ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، قَالَ حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّهُ حَدَّثَهُ أَنَّ رَجُلاً مِنَ الأَنْصَارِ خَاصَمَ الزُّبَيْرَ فِي شِرَاجٍ مِنَ الْحَرَّةِ يَسْقِي بِهَا النَّخْلَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْقِ يَا زُبَيْرُ ـ فَأَمَرَهُ بِالْمَعْرُوفِ ـ ثُمَّ أَرْسِلْ إِلَى جَارِكَ ‏"‏‏.‏ فَقَالَ الأَنْصَارِيُّ أَنْ كَانَ ابْنَ عَمَّتِكَ‏.‏ فَتَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ اسْقِ ثُمَّ احْبِسْ حَتَّى يَرْجِعَ الْمَاءُ إِلَى الْجَدْرِ ‏"‏‏.‏ وَاسْتَوْعَى لَهُ حَقَّهُ‏.‏ فَقَالَ الزُّبَيْرُ وَاللَّهِ إِنَّ هَذِهِ الآيَةَ أُنْزِلَتْ فِي ذَلِكَ ‏\{‏َلاَ وَرَبِّكِ لاَ يُؤْمِنُونَ حَتَّى يُحَكِّمُوكَ فِيمَا شَجَرَ بَيْنَهُمْ‏\}‏‏.‏ قَالَ لِي ابْنُ شِهَابٍ فَقَدَّرَتِ الأَنْصَارُ وَالنَّاسُ قَوْلَ النَّبِيِّ صلى الله عليه وسلم ‏"‏ اسْقِ ثُمَّ احْبِسْ حَتَّى يَرْجِعَ إِلَى الْجَدْرِ ‏"‏‏.‏ وَكَانَ ذَلِكَ إِلَى الْكَعْبَيْنِ‏.‏\hadithno{2362}\hadithtrans{Narrated `Urwa bin Az-Zubair:An Ansari man quarreled with Az-Zubair about a canal in the Harra which was used for irrigating date-palms. Allah's Messenger (ﷺ), ordering Zubair to be moderate, said, "O Zubair! Irrigate (your land) first and then leave the water for your neighbor." The Ansari said, "Is it because he is your aunt's son?" On that the color of the face of Allah's Messenger (ﷺ) changed and he said, "O Zubair! Irrigate (your land) and withhold the water till it reaches the walls that are between the pits around the trees." So, Allah's Apostle gave Zubair his full right. Zubair said, "By Allah, the following verse was revealed in that connection": "But no, by your Lord They can have No faith Until they make you judge In all disputes between them." (4.65) (The sub-narrator,) Ibn Shihab said to Juraij (another sub-narrator), "The Ansar and the other people interpreted the saying of the Prophet, 'Irrigate (your land) and withhold the water till it reaches the walls between the pits around the trees,' as meaning up to the ankles}}
\hadithdefcmd{bukhari}{2363}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَا رَجُلٌ يَمْشِي فَاشْتَدَّ عَلَيْهِ الْعَطَشُ، فَنَزَلَ بِئْرًا فَشَرِبَ مِنْهَا، ثُمَّ خَرَجَ فَإِذَا هُوَ بِكَلْبٍ يَلْهَثُ، يَأْكُلُ الثَّرَى مِنَ الْعَطَشِ، فَقَالَ لَقَدْ بَلَغَ هَذَا مِثْلُ الَّذِي بَلَغَ بِي فَمَلأَ خُفَّهُ ثُمَّ أَمْسَكَهُ بِفِيهِ، ثُمَّ رَقِيَ، فَسَقَى الْكَلْبَ فَشَكَرَ اللَّهُ لَهُ، فَغَفَرَ لَهُ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ، وَإِنَّ لَنَا فِي الْبَهَائِمِ أَجْرًا قَالَ ‏"‏ فِي كُلِّ كَبِدٍ رَطْبَةٍ أَجْرٌ ‏"‏‏.‏ تَابَعَهُ حَمَّادُ بْنُ سَلَمَةَ وَالرَّبِيعُ بْنُ مُسْلِمٍ عَنْ مُحَمَّدِ بْنِ زِيَادٍ‏.‏\hadithno{2363}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "While a man was walking he felt thirsty and went down a well and drank water from it. On coming out of it, he saw a dog panting and eating mud because of excessive thirst. The man said, 'This (dog) is suffering from the same problem as that of mine. So he (went down the well), filled his shoe with water, caught hold of it with his teeth and climbed up and watered the dog. Allah thanked him for his (good) deed and forgave him." The people asked, "O Allah's Messenger (ﷺ)! Is there a reward for us in serving (the) animals?" He replied, "Yes, there is a reward for serving any animate}}
\hadithdefcmd{bukhari}{2364}{حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى صَلاَةَ الْكُسُوفِ، فَقَالَ ‏ "‏ دَنَتْ مِنِّي النَّارُ حَتَّى قُلْتُ أَىْ رَبِّ، وَأَنَا مَعَهُمْ فَإِذَا امْرَأَةٌ ـ حَسِبْتُ أَنَّهُ قَالَ ـ تَخْدِشُهَا هِرَّةٌ قَالَ مَا شَأْنُ هَذِهِ قَالُوا حَبَسَتْهَا حَتَّى مَاتَتْ جُوعًا ‏"‏‏.‏\hadithno{2364}\hadithtrans{Narrated Asma' bint Abi Bakr:The Prophet (ﷺ) prayed the eclipse prayer, and then said, "Hell was displayed so close that I said, 'O my Lord ! Am I going to be one of its inhabitants?"' Suddenly he saw a woman. I think he said, who was being scratched by a cat. He said, "What is wrong with her?" He was told, "She had imprisoned it (i.e. the cat) till it died of hunger}}
\hadithdefcmd{bukhari}{2365}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عُذِّبَتِ امْرَأَةٌ فِي هِرَّةٍ حَبَسَتْهَا، حَتَّى مَاتَتْ جُوعًا، فَدَخَلَتْ فِيهَا النَّارَ ـ قَالَ فَقَالَ وَاللَّهُ أَعْلَمُ ـ لاَ أَنْتِ أَطْعَمْتِهَا وَلاَ سَقَيْتِهَا حِينَ حَبَسْتِيهَا، وَلاَ أَنْتِ أَرْسَلْتِيهَا فَأَكَلَتْ مِنْ خَشَاشِ الأَرْضِ ‏"‏‏.‏\hadithno{2365}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "A woman was tortured and was put in Hell because of a cat which she had kept locked till it died of hunger." Allah's Messenger (ﷺ) further said, (Allah knows better) Allah said (to the woman), 'You neither fed it nor watered when you locked it up, nor did you set it free to eat the vermin of the earth}}
\hadithdefcmd{bukhari}{2366}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَدَحٍ فَشَرِبَ وَعَنْ يَمِينِهِ غُلاَمٌ، هُوَ أَحْدَثُ الْقَوْمِ، وَالأَشْيَاخُ عَنْ يَسَارِهِ قَالَ ‏ "‏ يَا غُلاَمُ أَتَأْذَنُ لِي أَنْ أُعْطِيَ الأَشْيَاخَ ‏"‏‏.‏ فَقَالَ مَا كُنْتُ لأُوثِرَ بِنَصِيبِي مِنْكَ أَحَدًا يَا رَسُولَ اللَّهِ‏.‏ فَأَعْطَاهُ إِيَّاهُ‏.‏\hadithno{2366}\hadithtrans{Narrated Sahl bin Sa`d:Once a tumbler (full of milk or water) was brought to Allah's Messenger (ﷺ) who drank from it, while on his right side there was sitting a boy who was the youngest of those who were present, and on his left side there were old men. The Prophet (ﷺ) asked, "O boy ! Do you allow me to give (the drink) to the elder people (first)?" The boy said, "I will not prefer anybody to have my share from you, O Allah's Apostle!" So, he gave it to the boy}}
\hadithdefcmd{bukhari}{2367}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَذُودَنَّ رِجَالاً عَنْ حَوْضِي كَمَا تُذَادُ الْغَرِيبَةُ مِنَ الإِبِلِ عَنِ الْحَوْضِ ‏"‏‏.‏\hadithno{2367}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "By Him in Whose Hands my soul is, I will drive some people out from my (sacred) Fount on the Day of Resurrection as strange camels are expelled from a private trough}}
\hadithdefcmd{bukhari}{2368}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، وَكَثِيرِ بْنِ كَثِيرٍ ـ يَزِيدُ أَحَدُهُمَا عَلَى الآخَرِ ـ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَرْحَمُ اللَّهُ أُمَّ إِسْمَاعِيلَ، لَوْ تَرَكَتْ زَمْزَمَ ـ أَوْ قَالَ لَوْ لَمْ تَغْرِفْ مِنَ الْمَاءِ ـ لَكَانَتْ عَيْنًا مَعِينًا، وَأَقْبَلَ جُرْهُمُ فَقَالُوا أَتَأْذَنِينَ أَنْ نَنْزِلَ عِنْدَكِ قَالَتْ نَعَمْ وَلاَ حَقَّ لَكُمْ فِي الْمَاءِ‏.‏ قَالُوا نَعَمْ ‏"‏‏.‏\hadithno{2368}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "May Allah be merciful to the mother of Ishmael! If she had left the water of Zamzam (fountain) as it was, (without constructing a basin for keeping the water), (or said, "If she had not taken handfuls of its water"), it would have been a flowing stream. Jurhum (an Arab tribe) came and asked her, 'May we settle at your dwelling?' She said, 'Yes, but you have no right to possess the water.' They agreed}}
\hadithdefcmd{bukhari}{2369}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ يَوْمَ الْقِيَامَةِ، وَلاَ يَنْظُرُ إِلَيْهِمْ رَجُلٌ حَلَفَ عَلَى سِلْعَةٍ لَقَدْ أَعْطَى بِهَا أَكْثَرَ مِمَّا أَعْطَى وَهْوَ كَاذِبٌ، وَرَجُلٌ حَلَفَ عَلَى يَمِينٍ كَاذِبَةٍ بَعْدَ الْعَصْرِ لِيَقْتَطِعَ بِهَا مَالَ رَجُلٍ مُسْلِمٍ، وَرَجُلٌ مَنَعَ فَضْلَ مَاءٍ، فَيَقُولُ اللَّهُ الْيَوْمَ أَمْنَعُكَ فَضْلِي، كَمَا مَنَعْتَ فَضْلَ مَا لَمْ تَعْمَلْ يَدَاكَ ‏"‏‏.‏ قَالَ عَلِيٌّ حَدَّثَنَا سُفْيَانُ غَيْرَ مَرَّةٍ عَنْ عَمْرٍو سَمِعَ أَبَا صَالِحٍ يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم‏.‏\hadithno{2369}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "There are three types of people whom Allah will neither talk to, nor look at, on the Day of Resurrection. (They are): -1. A man who takes an oath falsely that he has been offered for his goods so much more than what he is given, -2. a man who takes a false oath after the `Asr prayer in order to grab a Muslim's property, and -3. a man who withholds his superfluous water. Allah will say to him, "Today I will withhold My Grace from you as you withheld the superfluity of what you had not created}}
\hadithdefcmd{bukhari}{2370}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ الصَّعْبَ بْنَ جَثَّامَةَ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ حِمَى إِلاَّ لِلَّهِ وَلِرَسُولِهِ ‏"‏‏.‏ وَقَالَ بَلَغَنَا أَنَّ النَّبِيَّ صلى الله عليه وسلم حَمَى النَّقِيعَ، وَأَنَّ عُمَرَ حَمَى السَّرَفَ وَالرَّبَذَةَ‏.‏\hadithno{2370}\hadithtrans{Narrated As-Sab bin Jath-thama:Allah's Messenger (ﷺ) said, No Hima except for Allah and His Apostle. We have been told that Allah's Apostle made a place called An-Naqi' as Hima, and `Umar made As-Saraf and Ar-Rabadha Hima (for grazing the animals of Zakat)}}
\hadithdefcmd{bukhari}{2371}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْخَيْلُ لِرَجُلٍ أَجْرٌ، وَلِرَجُلٍ سِتْرٌ، وَعَلَى رَجُلٍ وِزْرٌ، فَأَمَّا الَّذِي لَهُ أَجْرٌ فَرَجُلٌ رَبَطَهَا فِي سَبِيلِ اللَّهِ، فَأَطَالَ بِهَا فِي مَرْجٍ أَوْ رَوْضَةٍ، فَمَا أَصَابَتْ فِي طِيَلِهَا ذَلِكَ مِنَ الْمَرْجِ أَوِ الرَّوْضَةِ كَانَتْ لَهُ حَسَنَاتٍ، وَلَوْ أَنَّهُ انْقَطَعَ طِيَلُهَا فَاسْتَنَّتْ شَرَفًا أَوْ شَرَفَيْنِ كَانَتْ آثَارُهَا وَأَرْوَاثُهَا حَسَنَاتٍ لَهُ، وَلَوْ أَنَّهَا مَرَّتْ بِنَهَرٍ فَشَرِبَتْ مِنْهُ وَلَمْ يُرِدْ أَنْ يَسْقِيَ كَانَ ذَلِكَ حَسَنَاتٍ لَهُ، فَهِيَ لِذَلِكَ أَجْرٌ، وَرَجُلٌ رَبَطَهَا تَغَنِّيًا وَتَعَفُّفًا ثُمَّ لَمْ يَنْسَ حَقَّ اللَّهِ فِي رِقَابِهَا وَلاَ ظُهُورِهَا، فَهِيَ لِذَلِكَ سِتْرٌ، وَرَجُلٌ رَبَطَهَا فَخْرًا وَرِيَاءً وَنِوَاءً لأَهْلِ الإِسْلاَمِ، فَهِيَ عَلَى ذَلِكَ وِزْرٌ ‏"‏‏.‏ وَسُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْحُمُرِ فَقَالَ ‏"‏ مَا أُنْزِلَ عَلَىَّ فِيهَا شَىْءٌ إِلاَّ هَذِهِ الآيَةُ الْجَامِعَةُ الْفَاذَّةُ ‏\{‏َمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ خَيْرًا يَرَهُ * وَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ شَرًّا يَرَهُ ‏\}‏‏"‏\hadithno{2371}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Keeping horses may be a source of reward to some (man), a shelter to another (i.e. means of earning one's living), or a burden to a third. He to whom the horse will be a source of reward is the one who keeps it in Allah's Cause (prepare it for holy battles) and ties it by a long rope in a pasture (or a garden). He will get a reward equal to what its long rope allows it to eat in the pasture or the garden, and if that horse breaks its rope and crosses one or two hills, then all its footsteps and its dung will be counted as good deeds for its owner; and if it passes by a river and drinks from it, then that will also be regarded as a good deed for its owner even if he has had no intention of watering it then. Horses are a shelter from poverty to the second person who keeps horses for earning his living so as not to ask others, and at the same time he gives Allah's right (i.e. Zak`at) (from the wealth he earns through using them in trading etc.,) and does not overburden them. He who keeps horses just out of pride and for showing off and as a means of harming the Muslims, his horses will be a source of sins to him." When Allah's Messenger (ﷺ) was asked about donkeys, he replied, "Nothing particular was revealed to me regarding them except the general unique verse which is applicable to everything: "Whoever does goodness equal to the weight of an atom (or small ant) shall see it (its reward) on the Day of Resurrection}}
\hadithdefcmd{bukhari}{2372}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا مَالِكٌ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ ـ رضى الله عنه ـ قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ عَنِ اللُّقَطَةِ، فَقَالَ ‏"‏ اعْرِفْ عِفَاصَهَا وَوِكَاءَهَا، ثُمَّ عَرِّفْهَا سَنَةً، فَإِنْ جَاءَ صَاحِبُهَا وَإِلاَّ فَشَأْنَكَ بِهَا ‏"‏‏.‏ قَالَ فَضَالَّةُ الْغَنَمِ قَالَ ‏"‏ هِيَ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏‏.‏ قَالَ فَضَالَّةُ الإِبِلِ قَالَ ‏"‏ مَالَكَ وَلَهَا مَعَهَا سِقَاؤُهَا وَحِذَاؤُهَا، تَرِدُ الْمَاءَ وَتَأْكُلُ الشَّجَرَ، حَتَّى يَلْقَاهَا رَبُّهَا ‏"‏‏.‏\hadithno{2372}\hadithtrans{Narrated Zaid bin Khalid:A man came to Allah's Messenger (ﷺ) and asked about Al-Luqata (a fallen thing). The Prophet (ﷺ) said, "Recognize its container and its tying material and then make a public announcement about it for one year and if its owner shows up, give it to him; otherwise use it as you like." The man said, "What about a lost sheep?" The Prophet (ﷺ) said, "It is for you, your brother or the wolf." The man said "What about a lost camel?" The Prophet (ﷺ) said, "Why should you take it as it has got its water-container (its stomach) and its hooves and it can reach the places of water and can eat the trees till its owner finds it?}}
\hadithdefcmd{bukhari}{2373}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنِ الزُّبَيْرِ بْنِ الْعَوَّامِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لأَنْ يَأْخُذَ أَحَدُكُمْ أَحْبُلاً، فَيَأْخُذَ حُزْمَةً مِنْ حَطَبٍ فَيَبِيعَ، فَيَكُفَّ اللَّهُ بِهِ وَجْهَهُ، خَيْرٌ مِنْ أَنْ يَسْأَلَ النَّاسَ أُعْطِيَ أَمْ مُنِعَ ‏"‏‏.‏\hadithno{2373}\hadithtrans{Narrated Az-Zubair bin Al 'Awwam:The Prophet (ﷺ) said, "No doubt, one had better take a rope (and cut) and tie a bundle of wood and sell it whereby Allah will keep his face away (from Hell-fire) rather than ask others who may give him or not}}
\hadithdefcmd{bukhari}{2374}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ يَحْتَطِبَ أَحَدُكُمْ حُزْمَةً عَلَى ظَهْرِهِ خَيْرٌ لَهُ مِنْ أَنْ يَسْأَلَ أَحَدًا فَيُعْطِيَهُ أَوْ يَمْنَعَهُ ‏"‏‏.‏\hadithno{2374}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "No doubt, you had better gather a bundle of wood and carry it on your back (and earn your living thereby) rather than ask somebody who may give you or not}}
\hadithdefcmd{bukhari}{2375}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي ابْنُ شِهَابٍ، عَنْ عَلِيِّ بْنِ حُسَيْنِ بْنِ عَلِيٍّ، عَنْ أَبِيهِ، حُسَيْنِ بْنِ عَلِيٍّ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ ـ رضى الله عنهم ـ أَنَّهُ قَالَ أَصَبْتُ شَارِفًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي مَغْنَمٍ يَوْمَ بَدْرٍ قَالَ وَأَعْطَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم شَارِفًا أُخْرَى، فَأَنَخْتُهُمَا يَوْمًا عِنْدَ باب رَجُلٍ مِنَ الأَنْصَارِ، وَأَنَا أُرِيدُ أَنْ أَحْمِلَ عَلَيْهِمَا إِذْخِرًا لأَبِيعَهُ، وَمَعِي صَائِغٌ مِنْ بَنِي قَيْنُقَاعَ فَأَسْتَعِينَ بِهِ عَلَى وَلِيمَةِ فَاطِمَةَ، وَحَمْزَةُ بْنُ عَبْدِ الْمُطَّلِبِ يَشْرَبُ فِي ذَلِكَ الْبَيْتِ مَعَهُ قَيْنَةٌ، فَقَالَتْ أَلاَ يَا حَمْزَ لِلشُّرُفِ النِّوَاءِ‏.‏ فَثَارَ إِلَيْهِمَا حَمْزَةُ بِالسَّيْفِ، فَجَبَّ أَسْنِمَتَهُمَا، وَبَقَرَ خَوَاصِرَهُمَا، ثُمَّ أَخَذَ مِنْ أَكْبَادِهِمَا‏.‏ قُلْتُ لاِبْنِ شِهَابٍ وَمِنَ السَّنَامِ قَالَ قَدْ جَبَّ أَسْنِمَتَهُمَا فَذَهَبَ بِهَا‏.‏ قَالَ ابْنُ شِهَابٍ قَالَ عَلِيٌّ ـ رضى الله عنه ـ فَنَظَرْتُ إِلَى مَنْظَرٍ أَفْظَعَنِي فَأَتَيْتُ نَبِيَّ اللَّهِ صلى الله عليه وسلم وَعِنْدَهُ زَيْدُ بْنُ حَارِثَةَ فَأَخْبَرْتُهُ الْخَبَرَ فَخَرَجَ وَمَعَهُ زَيْدٌ، فَانْطَلَقْتُ مَعَهُ، فَدَخَلَ عَلَى حَمْزَةَ فَتَغَيَّظَ عَلَيْهِ فَرَفَعَ حَمْزَةُ بَصَرَهُ وَقَالَ هَلْ أَنْتُمْ إِلاَّ عَبِيدٌ لآبَائِي فَرَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَهْقِرُ حَتَّى خَرَجَ عَنْهُمْ، وَذَلِكَ قَبْلَ تَحْرِيمِ الْخَمْرِ‏.‏\hadithno{2375}\hadithtrans{Narrated Husain bin `Ali:`Ali bin Abi Talib said: "I got a she-camel as my share of the war booty on the day (of the battle) of Badr, and Allah's Messenger (ﷺ) gave me another she-camel. I let both of them kneel at the door of one of the Ansar, intending to carry Idhkhir on them to sell it and use its price for my wedding banquet on marrying Fatima. A goldsmith from Bani Qainqa' was with me. Hamza bin `Abdul-Muttalib was in that house drinking wine and a lady singer was reciting: "O Hamza! (Kill) the (two) fat old she camels (and serve them to your guests). So Hamza took his sword and went towards the two she-camels and cut off their humps and opened their flanks and took a part of their livers." (I said to Ibn Shihab, "Did he take part of the humps?" He replied, "He cut off their humps and carried them away.") `Ali further said, "When I saw that dreadful sight, I went to the Prophet (ﷺ) and told him the news. The Prophet (ﷺ) came out in the company of Zaid bin Haritha who was with him then, and I too went with them. He went to Hamza and spoke harshly to him. Hamza looked up and said, 'Aren't you only the slaves of my forefathers?' The Prophet (ﷺ) retreated and went out. This incident happened before the prohibition of drinking}}
\hadithdefcmd{bukhari}{2376}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ قَالَ أَرَادَ النَّبِيُّ صلى الله عليه وسلم أَنْ يُقْطِعَ مِنَ الْبَحْرَيْنِ، فَقَالَتِ الأَنْصَارُ حَتَّى تُقْطِعَ لإِخْوَانِنَا مِنَ الْمُهَاجِرِينَ مِثْلَ الَّذِي تُقْطِعُ لَنَا قَالَ ‏ "‏ سَتَرَوْنَ بَعْدِي أَثَرَةً فَاصْبِرُوا حَتَّى تَلْقَوْنِي ‏"‏‏.‏\hadithno{2376}\hadithtrans{Narrated Anas:The Prophet (ﷺ) decided to grant a portion of (the uncultivated land of) Bahrain to the Ansar. The Ansar said, "(We will not accept it) till you give a similar portion to our emigrant brothers (from Quraish)." He said, "(O Ansar!) You will soon see people giving preference to others, so remain patient till you meet me (on the Day of Resurrection)}}
\hadithdefcmd{bukhari}{2377}{وَقَالَ اللَّيْثُ عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ دَعَا النَّبِيُّ صلى الله عليه وسلم الأَنْصَارَ لِيُقْطِعَ لَهُمْ بِالْبَحْرَيْنِ، فَقَالُوا يَا رَسُولَ اللَّهِ إِنْ فَعَلْتَ فَاكْتُبْ لإِخْوَانِنَا مِنْ قُرَيْشٍ بِمِثْلِهَا، فَلَمْ يَكُنْ ذَلِكَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّكُمْ سَتَرَوْنَ بَعْدِي أَثَرَةً فَاصْبِرُوا حَتَّى تَلْقَوْنِي ‏"‏‏.‏\hadithno{2377}\hadithtrans{Narrated Anas (ra):The Prophet (ﷺ) called the Ansar so as to grant them a portion of (the land of) Bahrain. They said, "O Allah's Messenger ! If you grant this to us, write a similar document on our Quraish (emigrant) brothers." But the Prophet (ﷺ) did not have enough grants and he said: "After me you will see the people giving preference (to others), so be patient till you meet me}}
\hadithdefcmd{bukhari}{2378}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُلَيْحٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ هِلاَلِ بْنِ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مِنْ حَقِّ الإِبِلِ أَنْ تُحْلَبَ عَلَى الْمَاءِ ‏"‏‏.‏\hadithno{2378}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "One of the rights of a she camel is that it should be milked at a place of water}}
\hadithdefcmd{bukhari}{2379}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ ابْتَاعَ نَخْلاً بَعْدَ أَنْ تُؤَبَّرَ فَثَمَرَتُهَا لِلْبَائِعِ، إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ، وَمَنِ ابْتَاعَ عَبْدًا وَلَهُ مَالٌ فَمَالُهُ لِلَّذِي بَاعَهُ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏‏.‏ وَعَنْ مَالِكٍ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنْ عُمَرَ فِي الْعَبْدِ‏.‏\hadithno{2379}\hadithtrans{Narrated 'Abdullah (ra): I heard the Messenger of Allah (ﷺ) say, "If somebody buys date-palms after they have been pollinated, the fruits will belong to the seller unless the buyer stipulates the contrary. If somebody buys a slave having some property, the property will belong to the seller unless the buyer stipulate that it should belong to him}}
\hadithdefcmd{bukhari}{2380}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ زَيْدِ بْنِ ثَابِتٍ ـ رضى الله عنهم ـ قَالَ رَخَّصَ النَّبِيُّ صلى الله عليه وسلم أَنْ تُبَاعَ الْعَرَايَا بِخَرْصِهَا تَمْرًا‏.‏\hadithno{2380}\hadithtrans{Narrated Zaid bin Thabit:The Prophet (ﷺ) permitted selling the dates of the 'Araya for ready dates by estimating the amount of the former (as they are still on the trees)}}
\hadithdefcmd{bukhari}{2381}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ الْمُخَابَرَةِ، وَالْمُحَاقَلَةِ، وَعَنِ الْمُزَابَنَةِ، وَعَنْ بَيْعِ الثَّمَرِ حَتَّى يَبْدُوَ صَلاَحُهَا، وَأَنْ لاَ تُبَاعَ إِلاَّ بِالدِّينَارِ وَالدِّرْهَمِ، إِلاَّ الْعَرَايَا‏.‏\hadithno{2381}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) forbade the sales called Al-Mukhabara, Al-Muhaqala and Al-Muzabana and the selling of fruits till they are free from blights. He forbade the selling of the fruits except for money, except the 'Araya}}
\hadithdefcmd{bukhari}{2382}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، أَخْبَرَنَا مَالِكٌ، عَنْ دَاوُدَ بْنِ حُصَيْنٍ، عَنْ أَبِي سُفْيَانَ، مَوْلَى أَبِي أَحْمَدَ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ رَخَّصَ النَّبِيُّ صلى الله عليه وسلم فِي بَيْعِ الْعَرَايَا بِخَرْصِهَا مِنَ التَّمْرِ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ أَوْ فِي خَمْسَةِ أَوْسُقٍ، شَكَّ دَاوُدُ فِي ذَلِكَ‏.‏\hadithno{2382}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) allowed the sale of the dates of the 'Araya for ready dates by estimating the former which should be estimated as less than five Awsuq or five Awsuq. (Dawud, the sub-narrator is not sure as to the right amount)}}
\hadithdefcmd{bukhari}{2383}{حَدَّثَنَا زَكَرِيَّاءُ بْنُ يَحْيَى، أَخْبَرَنَا أَبُو أُسَامَةَ، قَالَ أَخْبَرَنِي الْوَلِيدُ بْنُ كَثِيرٍ، قَالَ أَخْبَرَنِي بُشَيْرُ بْنُ يَسَارٍ، مَوْلَى بَنِي حَارِثَةَ أَنَّ رَافِعَ بْنَ خَدِيجٍ، وَسَهْلَ بْنَ أَبِي حَثْمَةَ، حَدَّثَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ بَيْعِ الثَّمَرِ بِالتَّمْرِ، إِلاَّ أَصْحَابَ الْعَرَايَا فَإِنَّهُ أَذِنَ لَهُمْ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَ ابْنُ إِسْحَاقَ حَدَّثَنِي بُشَيْرٌ مِثْلَهُ‏.‏\hadithno{2383}\hadithtrans{Narrated Rafi` 'bin Khadij and Sahl bin Abi Hathma:Allah's Messenger (ﷺ) forbade the sale of Muzabana, i.e. selling of fruits for fruits, except in the case of 'Araya; he allowed the owners of 'Araya such kind of sale}}
